@@ -25,7 +25,7 @@ use Module::Pluggable::Ordered
     except      => qr/^MojoMojo::Plugin::/,
     require     => 1;
 
-our $VERSION = '0.999024';
+our $VERSION = '0.999025';
 
 MojoMojo->config->{authentication}{dbic} = {
     user_class     => 'DBIC::Person',
@@ -506,14 +506,16 @@ sub check_permissions {
     return \%perms;
 }
 
+my $search_setup_failed = 0;
+
 MojoMojo->config->{index_dir}||=MojoMojo->path_to('index');
 MojoMojo->config->{attachment_dir}||=MojoMojo->path_to('uploads');
 unless (-e MojoMojo->config->{index_dir}) {
-    mkdir(MojoMojo->config->{index_dir}) || die 'Could not make index directory <'.MojoMojo->config->{index_dir}.'>';
+    mkdir(MojoMojo->config->{index_dir}) || warn 'Could not make index directory <'.MojoMojo->config->{index_dir}.'> FIX IT OR SEARCH WILL NOT WORK!' and $search_setup_failed = 1;
 }
-die 'Require write access to index <'.MojoMojo->config->{index_dir}.'>' unless (-w MojoMojo->config->{index_dir});
+warn 'Require write access to index <'.MojoMojo->config->{index_dir}.'> - FIX IT OR SEARCH WILL NOT WORK!' and $search_setup_failed = 1 unless (-w MojoMojo->config->{index_dir});
 
-MojoMojo->model('Search')->prepare_search_index() unless (-f MojoMojo->config->{index_dir}.'/segments'); 
+MojoMojo->model('Search')->prepare_search_index() if not -f MojoMojo->config->{index_dir}.'/segments' and not $search_setup_failed and not MojoMojo->pref('disable_search');
 unless (-e MojoMojo->config->{attachment_dir}) {
     mkdir(MojoMojo->config->{attachment_dir}) || die 'Could not make attachment directory <'.MojoMojo->config->{attachment_dir}.'>';
 }
